Crate memapi

memapi provides a minimal, no_std-friendly memory allocation interface for managing raw buffers, suitable for use in collections.

Modules

error
Errors which can occur during allocation.
ffi
FFI bindings to allocation libraries.
helpers
Helpers which tend to be useful in other libraries as well.
jemalloc
Module for jemalloc support.
marker
Marker traits.
mimalloc
Module for mimalloc support.
owned
Owned data types.
stats
Allocation statistic gathering and reporting.
type_props
Sized type properties as constants and property getters for pointers.
unstable_util
Small alternatives to Rust functions which are currently unstable.

Structs

DefaultAlloc
Default allocator, delegating to the global allocator.

Traits

Alloc
A memory allocation interface.
AllocExt
Extension methods for the core Alloc trait, providing convenient routines to allocate, initialize, clone, copy, and deallocate sized and unsized types.
AllocSlice
Slice-specific extension methods for Alloc, providing convenient functions for slice allocator operations.
AllocSliceExt
Slice-specific extension methods for AllocExt, providing extended convenient functions for slice allocator operations.
ResizeInPlace
Extension trait for Alloc which provides interfaces to reallocate in-place.