memapi provides a minimal, no_std-friendly memory allocation interface
for managing raw buffers, suitable for use in collections.
Modules
- error
- Errors which can occur during allocation.
- ffi
- FFI bindings to allocation libraries.
- helpers
- Helpers which tend to be useful in other libraries as well.
- jemalloc
- Module for jemalloc support.
- marker
- Marker traits.
- mimalloc
- Module for mimalloc support.
- owned
- Owned data types.
- stats
- Allocation statistic gathering and reporting.
- type_
props - Sized type properties as constants and property getters for pointers.
- unstable_
util - Small alternatives to Rust functions which are currently unstable.
Structs
- Default
Alloc - Default allocator, delegating to the global allocator.
Traits
- Alloc
- A memory allocation interface.
- Alloc
Ext - Extension methods for the core
Alloctrait, providing convenient routines to allocate, initialize, clone, copy, and deallocate sized and unsized types. - Alloc
Slice - Slice-specific extension methods for
Alloc, providing convenient functions for slice allocator operations. - Alloc
Slice Ext - Slice-specific extension methods for
AllocExt, providing extended convenient functions for slice allocator operations. - Resize
InPlace - Extension trait for
Allocwhich provides interfaces to reallocate in-place.